@@ -14,6 +14,7 @@ be put into classes in this module.
 
 import math
 import sys
+from collections import Counter
 
 from Bio.Seq import Seq
 
@@ -66,20 +67,20 @@ class SummaryInfo:
         # go through each seq item
         for n in range(con_len):
             # keep track of the counts of the different atoms we get
-            atom_dict = {}
+            atom_dict = Counter()
             num_atoms = 0
 
             for record in self.alignment:
                 # make sure we haven't run past the end of any sequences
                 # if they are of different lengths
-                if n < len(record.seq):
-                    if record.seq[n] != "-" and record.seq[n] != ".":
-                        if record.seq[n] not in atom_dict:
-                            atom_dict[record.seq[n]] = 1
-                        else:
-                            atom_dict[record.seq[n]] += 1
+                try:
+                    c = record[n]
+                except IndexError:
+                    continue
+                if c != "-" and c != ".":
+                    atom_dict[c] += 1
 
-                        num_atoms = num_atoms + 1
+                    num_atoms += 1
 
             max_atoms = []
             max_size = 0
@@ -93,9 +94,7 @@ class SummaryInfo:
 
             if require_multiple and num_atoms == 1:
                 consensus += ambiguous
-            elif (len(max_atoms) == 1) and (
-                (float(max_size) / float(num_atoms)) >= threshold
-            ):
+            elif len(max_atoms) == 1 and max_size / num_atoms >= threshold:
                 consensus += max_atoms[0]
             else:
                 consensus += ambiguous
@@ -122,19 +121,19 @@ class SummaryInfo:
         # go through each seq item
         for n in range(con_len):
             # keep track of the counts of the different atoms we get
-            atom_dict = {}
+            atom_dict = Counter()
             num_atoms = 0
 
             for record in self.alignment:
                 # make sure we haven't run past the end of any sequences
                 # if they are of different lengths
-                if n < len(record.seq):
-                    if record.seq[n] not in atom_dict:
-                        atom_dict[record.seq[n]] = 1
-                    else:
-                        atom_dict[record.seq[n]] += 1
+                try:
+                    c = record[n]
+                except IndexError:
+                    continue
+                atom_dict[c] += 1
 
-                    num_atoms += 1
+                num_atoms += 1
 
             max_atoms = []
             max_size = 0
@@ -148,9 +147,7 @@ class SummaryInfo:
 
             if require_multiple and num_atoms == 1:
                 consensus += ambiguous
-            elif (len(max_atoms) == 1) and (
-                (float(max_size) / float(num_atoms)) >= threshold
-            ):
+            elif len(max_atoms) == 1 and max_size / num_atoms >= threshold:
                 consensus += max_atoms[0]
             else:
                 consensus += ambiguous
@@ -260,7 +257,8 @@ class SummaryInfo:
         """
         # determine all of the letters we have to deal with
         all_letters = self._get_all_letters()
-        assert all_letters
+        if not all_letters:
+            raise ValueError("_get_all_letters returned empty string")
 
         if chars_to_ignore is None:
             chars_to_ignore = []
@@ -275,7 +273,10 @@ class SummaryInfo:
 
         if axis_seq:
             left_seq = axis_seq
-            assert len(axis_seq) == self.alignment.get_alignment_length()
+            if len(axis_seq) != self.alignment.get_alignment_length():
+                raise ValueError(
+                    "Axis sequence length does not equal the get_alignment_length"
+                )
         else:
             left_seq = self.dumb_consensus()
 
@@ -445,7 +446,8 @@ class SummaryInfo:
         if total_count == 0:
             # This column must be entirely ignored characters
             for letter in freq_info:
-                assert freq_info[letter] == 0
+                if freq_info[letter] != 0:
+                    raise ValueError("freq_info[letter] is not 0")
                 # TODO - Map this to NA or NaN?
         else:
             # now convert the counts into frequencies
@@ -589,6 +591,6 @@ def print_info_content(summary_info, fout=None, rep_record=0):
     fout = fout or sys.stdout
     if not summary_info.ic_vector:
         summary_info.information_content()
-    rep_sequence = summary_info.alignment[rep_record].seq
-    for pos, ic in enumerate(summary_info.ic_vector):
-        fout.write("%d %s %.3f\n" % (pos, rep_sequence[pos], ic))
+    rep_sequence = summary_info.alignment[rep_record]
+    for pos, (aa, ic) in enumerate(zip(rep_sequence, summary_info.ic_vector)):
+        fout.write("%d %s %.3f\n" % (pos, aa, ic))
