@@ -152,8 +152,6 @@ You can also see this in the Stockholm output of this partial-alignment:
     <BLANKLINE>
 
 """
-from collections import OrderedDict
-
 from Bio.Align import MultipleSeqAlignment
 from Bio.Seq import Seq
 from Bio.SeqRecord import SeqRecord
@@ -206,11 +204,9 @@ class StockholmWriter(SequentialAlignmentWriter):
         if alignment.column_annotations:
             for k, v in sorted(alignment.column_annotations.items()):
                 if k in self.pfam_gc_mapping:
-                    self.handle.write("#=GC %s %s\n" % (self.pfam_gc_mapping[k], v))
+                    self.handle.write(f"#=GC {self.pfam_gc_mapping[k]} {v}\n")
                 elif k in self.pfam_gr_mapping:
-                    self.handle.write(
-                        "#=GC %s %s\n" % (self.pfam_gr_mapping[k] + "_cons", v)
-                    )
+                    self.handle.write(f"#=GC {self.pfam_gr_mapping[k]}_cons {v}\n")
                 else:
                     # It doesn't follow the PFAM standards, but should we record
                     # this data anyway?
@@ -233,10 +229,7 @@ class StockholmWriter(SequentialAlignmentWriter):
         seq_name = seq_name.replace(" ", "_")
 
         if "start" in record.annotations and "end" in record.annotations:
-            suffix = "/%s-%s" % (
-                record.annotations["start"],
-                record.annotations["end"],
-            )
+            suffix = f"/{record.annotations['start']}-{record.annotations['end']}"
             if seq_name[-len(suffix) :] != suffix:
                 seq_name = "%s/%s-%s" % (
                     seq_name,
@@ -245,9 +238,9 @@ class StockholmWriter(SequentialAlignmentWriter):
                 )
 
         if seq_name in self._ids_written:
-            raise ValueError("Duplicate record identifier: %s" % seq_name)
+            raise ValueError(f"Duplicate record identifier: {seq_name}")
         self._ids_written.append(seq_name)
-        self.handle.write("%s %s\n" % (seq_name, record.seq))
+        self.handle.write(f"{seq_name} {record.seq}\n")
 
         # The recommended placement for GS lines (per sequence annotation)
         # is above the alignment (as a header block) or just below the
@@ -263,21 +256,18 @@ class StockholmWriter(SequentialAlignmentWriter):
         # AC = Accession
         if "accession" in record.annotations:
             self.handle.write(
-                "#=GS %s AC %s\n"
-                % (seq_name, self.clean(record.annotations["accession"]))
+                f"#=GS {seq_name} AC {self.clean(record.annotations['accession'])}\n"
             )
         elif record.id:
-            self.handle.write("#=GS %s AC %s\n" % (seq_name, self.clean(record.id)))
+            self.handle.write(f"#=GS {seq_name} AC {self.clean(record.id)}\n")
 
         # DE = description
         if record.description:
-            self.handle.write(
-                "#=GS %s DE %s\n" % (seq_name, self.clean(record.description))
-            )
+            self.handle.write(f"#=GS {seq_name} DE {self.clean(record.description)}\n")
 
         # DE = database links
         for xref in record.dbxrefs:
-            self.handle.write("#=GS %s DR %s\n" % (seq_name, self.clean(xref)))
+            self.handle.write(f"#=GS {seq_name} DR {self.clean(xref)}\n")
 
         # GS = other per sequence annotation
         for key, value in record.annotations.items():
@@ -381,7 +371,7 @@ class StockholmIterator(AlignmentIterator):
         # if present it agrees with our parsing.
 
         seqs = {}
-        ids = OrderedDict()  # Really only need an OrderedSet, but python lacks this
+        ids = {}  # Really only need an OrderedSet, but python lacks this
         gs = {}
         gr = {}
         gf = {}
@@ -554,7 +544,7 @@ class StockholmIterator(AlignmentIterator):
         return identifier, None, None
 
     def _get_meta_data(self, identifier, meta_dict):
-        """Take an itentifier and returns dict of all meta-data matching it (PRIVATE).
+        """Take an identifier and returns dict of all meta-data matching it (PRIVATE).
 
         For example, given "Q9PN73_CAMJE/149-220" will return all matches to
         this or "Q9PN73_CAMJE" which the identifier without its /start-end
